#!/bin/sh
dir=${0%/*}
if [ "$dir" = "$0" ]; then
  dir="."
fi
cd "$dir"


LIBRARY_PATH="/Library/Application Support/Propellerhead Software/Remote"  
BUNDLE_PATH="/Applications"  


LUA_FILES="Lua Codecs/JammeR"
MAP_FILES="Maps/JammeR"


# Install in Library if it exists
if [ -d "$LIBRARY_PATH" ]; then
  echo "Copying files to: $LIBRARY_PATH"
  cp -R "$LUA_FILES" "$LIBRARY_PATH/Codecs/Lua Codecs"
  cp -R "$MAP_FILES" "$LIBRARY_PATH/Maps"
  exit 0  
fi


#Get user permission to copy files
copy_with_admin_privileges() {
  local src="$1"
  local dest="$2"
  local message="This script needs your permission to copy files into the Reason application bundle."

  osascript -e "do shell script \"cp -R '$src' '$dest'\" with administrator privileges" -e "display dialog \"$message\" with title \"File Copy Permission\""
}

# Install in the app bundle
new_app_path=$(find "$BUNDLE_PATH" -type d -name "Reason *" -maxdepth 1 | head -n 1)

if [ -n "$new_app_path" ]; then
  echo "Copying files to: $new_app_path/Contents/Resources/Remote"
  copy_with_admin_privileges "Lua Codecs/JammeR" "$new_app_path/Contents/Resources/Remote/DefaultCodecs/Lua Codecs/"
  copy_with_admin_privileges "Maps/JammeR" "$new_app_path/Contents/Resources/Remote/DefaultMaps/"
  exit 0  # Exit the script after a successful copy
fi


# If no path was found
echo "Could not copy files, try manual copy and paste (see documentation)"
exit 1




